Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: pylib/gyp/common.py

Issue 9443044: Beginnings of some msvs_... emulation (windows ninja) (Closed) Base URL: https://gyp.googlecode.com/svn/trunk
Patch Set: no pdb option for LIB Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pylib/gyp/common.py
diff --git a/pylib/gyp/common.py b/pylib/gyp/common.py
index 614d207c30ab4607470a9627e53a6b8a248e74ea..a33efd0b2139731b3a7e7432d2bf32e4ba085719 100644
--- a/pylib/gyp/common.py
+++ b/pylib/gyp/common.py
@@ -361,9 +361,9 @@ def GetFlavor(params):
def CopyTool(flavor, out_path):
"""Finds (mac|sun)_tool.gyp in the gyp directory and copies it
to |out_path|."""
- prefix = { 'solaris': 'sun', 'mac': 'mac' }.get(flavor, None)
+ prefix = { 'solaris': 'sun', 'mac': 'mac', 'win': 'win' }.get(flavor, None)
Nico 2012/02/27 16:23:30 likewise
scottmg 2012/02/28 00:01:13 Done.
if not prefix:
@@ -361,9 +361,9 @@ def GetFlavor(params):
def CopyTool(flavor, out_path):
- """Finds (mac|sun)_tool.gyp in the gyp directory and copies it
+ """Finds (mac|sun|win)_tool.gyp in the gyp directory and copies it
to |out_path|."""
return

Powered by Google App Engine
This is Rietveld 408576698